@@ -1,7 +1,25 @@
 import logging
-from robotlibcore import DynamicCore
+import platform
+import sys
+import warnings
 
-from RPA.Desktop.utils import Buffer
+if platform.system() == "Windows":
+    # Configure comtypes to not generate DLL bindings into
+    # current environment, instead keeping them in memory.
+    # Slower, but prevents dirtying environments.
+    import comtypes.client
+
+    comtypes.client.gen_dir = None
+
+    # Ignore pywinauto warning about threading mode,
+    # which comtypes initializes to STA instead of MTA on import.
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", category=UserWarning)
+        import pywinauto
+
+# pylint: disable=wrong-import-position
+from robotlibcore import DynamicCore
+from RPA.Desktop.utils import Buffer, is_windows
 from RPA.Desktop.keywords import (
     ElementNotFound,
     MultipleElementsFound,
